moderation: decentralized moderation pools that can declare content as bad, etc. * there could be a USA moderation pool your gadget chooses a moderation pool to subscribe to, where then your gadget won't receive content that is filtered by that moderation pool. that is if an on chain { nft } is bad, the data is not given to you. centralized moderation pools, has the power to permanently erase metadata. as voted on by proof of stake of egalitarian-ish voting. can have variable number of members (with variable number of votes) issues: transaction history: instrument 1 sends: [ 1 to ... ], [ 1 to ... ], [ 1 to ... ] where array of send to addresses forms a bad image. -> not an issue if balance sheet model is used.